unit uniMain;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, StdCtrls, SPComm, ExtCtrls, ComCtrls;

type
  TfrmDrawer = class(TForm)
    Comm1: TComm;
    ComboBox1: TComboBox;
    btnStart: TButton;
    Label1: TLabel;
    btnOpen: TButton;
    btnStop: TButton;
    Label2: TLabel;
    edInterval: TEdit;
    UpDown1: TUpDown;
    Timer1: TTimer;
    Memo1: TMemo;
    StatusBar1: TStatusBar;
    procedure ComboBox1DropDown(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure btnStartClick(Sender: TObject);
    procedure btnOpenClick(Sender: TObject);
    procedure btnStopClick(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
    procedure UpdateAvailableCom;
    procedure UpdateCommStatus;
  end;

var
  frmDrawer: TfrmDrawer;

implementation
uses Registry;
{$R *.dfm}
procedure TfrmDrawer.UpdateAvailableCom;
var
  i: Integer;
  ComReg: TRegistry;
  ComName: string;
  ComList: TStringList;
begin
  ComboBox1.Clear;
  ComReg := TRegistry.Create;
  ComList := TStringList.Create;
  with ComReg do
  begin
    RootKey := HKEY_LOCAL_MACHINE;
    OpenKey('HARDWARE\DEVICEMAP\SERIALCOMM',false);
    try
      GetValueNames(ComList);
      for i:=0 to ComList.Count-1 do
      begin
        ComName := ReadString(ComList.Strings[i]);
        if CompareText('COM',Copy(ComName,1,3)) = 0 then
          ComboBox1.Items.Append(ComName);
      end;
    except
    end;
  end;
end;

procedure TfrmDrawer.UpdateCommStatus;
var
  MState: Cardinal;
  str: string;
begin
  MState := Comm1.GetModemState;
  str := Format('%8.8x',[MState]);
  if (MState and MS_CTS_ON) <> 0 then
    str := 'CTS ON'
  else
    str := 'CTS OFF';
  if (MState and MS_DSR_ON) <> 0 then
    str := str + ' DSR ON'
  else
    str := str + ' DSR OFF';
  StatusBar1.SimpleText := str;
end;

procedure TfrmDrawer.ComboBox1DropDown(Sender: TObject);
begin
  UpdateAvailableCom;
end;

procedure TfrmDrawer.FormCreate(Sender: TObject);
begin
  UpdateAvailableCom;
  if ComboBox1.Items.Count > 0 then
    ComboBox1.ItemIndex := 0
  else
    ComboBox1.ItemIndex := -1;
end;

procedure TfrmDrawer.btnStartClick(Sender: TObject);
begin
  if ComboBox1.Text = '' then
  begin
    ShowMessage('Please select the COM port first.');
    Exit;
  end;
  Comm1.CommName := ComboBox1.Text;
  try
    Comm1.StartComm;
    ComboBox1.Enabled := False;
    btnStart.Enabled := False;
    btnOpen.Enabled := True;
    btnStop.Enabled := True;
    UpDown1.Enabled := False;
    edInterval.Enabled := False;
    if UpDown1.Position > 0 then
    begin
      UpDown1.Enabled := False;
      Timer1.Interval := UpDown1.Position * 1000;
      Timer1.Enabled := True;
    end;
    UpdateCommStatus;
  except
    ShowMessage(Format('Can not open %s',[Comm1.CommName]));
  end;
end;

procedure TfrmDrawer.btnOpenClick(Sender: TObject);
begin
  UpdateCommStatus;
  Comm1.WriteCommData('1234',4);
end;

procedure TfrmDrawer.btnStopClick(Sender: TObject);
begin
  Comm1.StopComm;
  ComboBox1.Enabled := True;
  btnStart.Enabled := True;
  btnOpen.Enabled := False;
  btnStop.Enabled := False;
  UpDown1.Enabled := True;
  Timer1.Enabled := False;
  UpDown1.Enabled := True;
  edInterval.Enabled := True;
end;

end.
